==> npp.4.1.src.zip: PowerEditor/src/ScitillaComponent/FindReplaceDlg_rc.h <==


#define	IDD_FIND_REPLACE_DLG		1600
#define	IDFINDWHAT		1601
#define	IDREPLACEWITH		1602
#define	IDWHOLEWORD		1603
#define	IDMATCHCASE		1604
#define	IDREGEXP		1605
#define	IDWRAP		1606
#define	IDUNSLASH		1607
#define	IDREPLACE		1608
#define	IDREPLACEALL		1609
#define	IDREPLACEINSEL		1610
#define	ID_STATICTEXT_REPLACE	1611
#define	IDDIRECTIONUP		1612
#define	IDDIRECTIONDOWN 1613
#define	IDCCOUNTALL         1614
#define	IDCMARKALL           1615
#define	IDC_MARKLINE_CHECK    1616
#define	IDC_STYLEFOUND_CHECK    1617
#define	IDC_PURGE_CHECK    1618
#define	IDC_FINDALL_STATIC    1619
#define	IDFINDWHAT_STATIC		1620
#define	IDC_DIR_STATIC		1621
#define	IDC_PERCENTAGE_SLIDER   1622
#define	IDC_TRANSPARENT_CHECK  1623

#define	IDC_DISPLAYPOS_STATIC		1624
#define	IDC_DISPLAYPOS_TOP		1625
#define	IDC_DISPLAYPOS_MIDDLE   1626
#define	IDC_DISPLAYPOS_BOTTOM  1627

#define	IDC_FIND_IN_STATIC       1628
//#define	IDC_CURRENT_FILE_RADIO   1629
//#define	IDC_OPENED_FILES_RADIO   1630
//#define	IDC_FILES_RADIO          1631
#define	IDC_IN_SELECTION_CHECK   1632
#define	IDC_CLEAR_ALL            1633
#define	IDC_REPLACEINSELECTION   1634
#define	IDC_REPLACE_OPENEDFILES  1635
#define	IDC_FINDALL_OPENEDFILES  1636
//#define	IDC_FINDINFILES  1637
#define	IDC_FINDINFILES_LAUNCH  1638
#define	IDC_GETCURRENTDOCTYPE  1639
//#define	IDSWITCH  1640

#define	IDD_FINDINFILES_DLG 1650
#define	IDD_FINDINFILES_BROWSE_BUTTON 1651
#define	IDD_FINDINFILES_FILTERS_COMBO 1652
#define	IDD_FINDINFILES_DIR_COMBO 1653
#define	IDD_FINDINFILES_FILTERS_STATIC 1654
#define	IDD_FINDINFILES_DIR_STATIC 1655
#define	IDD_FINDINFILES_FIND_BUTTON 1656
#define	IDD_FINDINFILES_GOBACK_BUTTON 1657
#define	IDD_FINDINFILES_RECURSIVE_CHECK 1658

#define	IDD_FINDRESULT 1670

#define	IDD_INCREMENT_FIND 1680
#define	IDC_INCSTATIC 1681
#define	IDC_INCFINDTEXT 1682
#define	IDC_INCFINDPREVOK 1683
#define	IDC_INCFINDNXTOK 1684
#define	IDC_INCFINDMATCHCASE 1685

==> npp.4.7.3.src.zip: PowerEditor/src/ScitillaComponent/FindReplaceDlg_rc.h <==


#define	IDD_FIND_REPLACE_DLG		1600
#define	IDFINDWHAT		1601
#define	IDREPLACEWITH		1602
#define	IDWHOLEWORD		1603
#define	IDMATCHCASE		1604
#define	IDREGEXP		1605
#define	IDWRAP		1606
#define	IDUNSLASH		1607
#define	IDREPLACE		1608
#define	IDREPLACEALL		1609
#define	IDREPLACEINSEL		1610
#define	ID_STATICTEXT_REPLACE	1611
#define	IDDIRECTIONUP		1612
#define	IDDIRECTIONDOWN 1613
#define	IDCCOUNTALL         1614
#define	IDCMARKALL           1615
#define	IDC_MARKLINE_CHECK    1616
#define	IDC_STYLEFOUND_CHECK    1617
#define	IDC_PURGE_CHECK    1618
#define	IDC_FINDALL_STATIC    1619
#define	IDFINDWHAT_STATIC		1620
#define	IDC_DIR_STATIC		1621

#define	IDC_PERCENTAGE_SLIDER				1622
#define	IDC_TRANSPARENT_GRPBOX 				1623

#define	IDC_DISPLAYPOS_STATIC		1624
#define	IDC_DISPLAYPOS_TOP		1625
#define	IDC_DISPLAYPOS_MIDDLE   1626
#define	IDC_DISPLAYPOS_BOTTOM  1627

#define	IDC_FIND_IN_STATIC       1628
//#define	IDC_CURRENT_FILE_RADIO   1629
//#define	IDC_OPENED_FILES_RADIO   1630
//#define	IDC_FILES_RADIO          1631
#define	IDC_IN_SELECTION_CHECK   1632
#define	IDC_CLEAR_ALL            1633
#define	IDC_REPLACEINSELECTION   1634
#define	IDC_REPLACE_OPENEDFILES  1635
#define	IDC_FINDALL_OPENEDFILES  1636
//#define	IDC_FINDINFILES  1637
#define	IDC_FINDINFILES_LAUNCH  1638
#define	IDC_GETCURRENTDOCTYPE  1639
//#define	IDSWITCH  1640

#define	IDD_FINDINFILES_DLG 1650
#define	IDD_FINDINFILES_BROWSE_BUTTON 1651
#define	IDD_FINDINFILES_FILTERS_COMBO 1652
#define	IDD_FINDINFILES_DIR_COMBO 1653
#define	IDD_FINDINFILES_FILTERS_STATIC 1654
#define	IDD_FINDINFILES_DIR_STATIC 1655
#define	IDD_FINDINFILES_FIND_BUTTON 1656
#define	IDD_FINDINFILES_GOBACK_BUTTON 1657
#define	IDD_FINDINFILES_RECURSIVE_CHECK 1658

#define	IDD_FINDRESULT 1670

#define	IDD_INCREMENT_FIND 1680
#define	IDC_INCSTATIC 1681
#define	IDC_INCFINDTEXT 1682
#define	IDC_INCFINDPREVOK 1683
#define	IDC_INCFINDNXTOK 1684
#define	IDC_INCFINDMATCHCASE 1685

#define	IDC_TRANSPARENT_CHECK				1686
#define	IDC_TRANSPARENT_LOSSFOCUS_RADIO		1687
#define	IDC_TRANSPARENT_ALWAYS_RADIO		1688
